|PyPI Version| |Build Status| |Coverage Status| |Python Version|

This Python package provides `Babel extractors <http://babel.pocoo.org/en/latest/messages.html>`__ and translation methods for standards that use JSON Schema and CSV codelists with `custom JSON Schema properties <https://os4d.opendataservices.coop/development/schema/#extended-json-schema>`__, like the Open Contracting Data Standard (OCDS) or Beneficial Ownership Data Standard (BODS).

If you are viewing this on GitHub or PyPi, open the `full documentation <https://ocds-babel.readthedocs.io/>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/ocds-babel.svg
   :target: https://pypi.org/project/ocds-babel/
.. |Build Status| image:: https://secure.travis-ci.org/open-contracting/ocds-babel.png
   :target: https://travis-ci.org/open-contracting/ocds-babel
.. |Coverage Status| image:: https://coveralls.io/repos/github/open-contracting/ocds-babel/badge.png?branch=master
   :target: https://coveralls.io/github/open-contracting/ocds-babel?branch=master
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ocds-babel.svg
   :target: https://pypi.org/project/ocds-babel/
